#[non_exhaustive]pub struct CosmosAccountReference { /* private fields */ }Expand description
A reference to a Cosmos DB account, combining an endpoint with a credential.
This type bundles together the account endpoint and the credential needed to
authenticate with it. Use convenience constructors with_credential()
or with_master_key() to create instances.
Examples
Using Entra ID authentication:
use azure_data_cosmos::{CosmosAccountReference, CosmosAccountEndpoint};
use std::sync::Arc;
let credential: Arc<dyn azure_core::credentials::TokenCredential> =
azure_identity::DeveloperToolsCredential::new(None).unwrap();
let endpoint: CosmosAccountEndpoint = "https://myaccount.documents.azure.com/".parse().unwrap();
let account = CosmosAccountReference::with_credential(endpoint, credential);Using key authentication (requires key_auth feature):
ⓘ
use azure_data_cosmos::{CosmosAccountReference, CosmosAccountEndpoint};
use azure_core::credentials::Secret;
let endpoint: CosmosAccountEndpoint = "https://myaccount.documents.azure.com/".parse().unwrap();
let account = CosmosAccountReference::with_master_key(endpoint, Secret::from("my_account_key"));Implementations
Sourceimpl CosmosAccountReference
impl CosmosAccountReference
Sourcepub fn with_credential(
endpoint: CosmosAccountEndpoint,
credential: Arc<dyn TokenCredential>,
) -> Self
pub fn with_credential( endpoint: CosmosAccountEndpoint, credential: Arc<dyn TokenCredential>, ) -> Self
Creates a new account reference with an Entra ID (Azure AD) token credential.
Arguments
endpoint- The Cosmos DB account endpoint.credential- An Entra ID token credential.
Sourcepub fn with_master_key(endpoint: CosmosAccountEndpoint, key: Secret) -> Self
Available on crate feature key_auth only.
pub fn with_master_key(endpoint: CosmosAccountEndpoint, key: Secret) -> Self
key_auth only.Creates a new account reference with a master key.
Arguments
endpoint- The Cosmos DB account endpoint.key- The primary or secondary account key.